@@ -2,23 +2,29 @@ from datetime import datetime
 from typing import Any, List, Union, Tuple, Optional
 
 from bson import ObjectId
-from firebase_admin.exceptions import NotFoundError, ALREADY_EXISTS, ConflictError
+from google.api_core.exceptions import NotFound, AlreadyExists, Conflict
 from google.cloud.firestore_v1.collection import CollectionReference
+from google.cloud.firestore import Client
 from pydantic import BaseModel
 
-from firestore_collections.client import client
 from firestore_collections.enums import OrderByDirection
 from firestore_collections.utils import chunks, parse_document_to_dict
 
 
 class Collection:
-    def __init__(self, schema: BaseModel):
+    def __init__(self, schema: BaseModel, firestore_client: Optional[Client] = None):
         self.schema = schema
         self.collection_name = schema.__collection_name__
 
         if self.collection_name is None:
             raise ValueError('`__collection_name__` has not been defined')
 
+        if firestore_client is None:
+            from firestore_collections.client import client
+            self._client = client
+        else:
+            self._client = firestore_client
+
     @property
     def name(self):
         return self.schema.__name__
@@ -28,14 +34,14 @@ class Collection:
 
     @property
     def collection(self) -> CollectionReference:
-        return client.collection(self.collection_name)
+        return self._client.collection(self.collection_name)
 
     def get(self, id: str) -> Any:
         doc_ref = self.collection.document(id)
         doc = doc_ref.get()
 
         if not doc.exists:
-            raise NotFoundError(f"Document {self.collection_name}.{id} could not be found")
+            raise NotFound(f"Document {self.collection_name}.{id} could not be found")
 
         return self.schema(**{**doc.to_dict(), 'id': doc.id})
 
@@ -48,7 +54,7 @@ class Collection:
     def get_by_attribute(self, attribute: str, value: Any) -> Any:
         docs = self.query_by_attribute(attribute=attribute, value=value)
         if len(docs) == 0:
-            raise NotFoundError(f"Document could not be found in {self.collection_name} with `{attribute}=={value}`")
+            raise NotFound(f"Document could not be found in {self.collection_name} with `{attribute}=={value}`")
 
         return docs[0]
 
@@ -221,7 +227,7 @@ class Collection:
         else:
             # Check if document already exists
             if self.collection.document(new_id).get().exists:
-                raise ALREADY_EXISTS(f"{self.schema.__name__} already exists with ID: {new_id}")
+                raise AlreadyExists(f"{self.schema.__name__} already exists with ID: {new_id}")
         doc_ref = self.collection.document(new_id)
         doc_ref.set(doc)
 
@@ -244,7 +250,7 @@ class Collection:
                 if is_update and doc.id == doc_db.id:
                     continue
 
-                raise ConflictError(f"{self.name} with {key} {value} already exists")
-            except NotFoundError:
+                raise Conflict(f"{self.name} with {key} {value} already exists")
+            except NotFound:
                 # No document with given unique key found
                 pass
